Bibliography — gcmpy documentation

# Bibliography

Istvan Kiss, Joel Miller, and Peter Simon. Mathematics of epidemics on networks. Springer series on Interdisciplinary Applied Mathematics 46. ISBN 978-3-319-50804-7. 2017.

Joel Miller. Percolation and epidemics in random clustered networks. Physical Review E 80. August 2009.

Sergey Melnik, Adam Hackett, Mason Porter, Peter Mucha, and James Gleeson. The unreasonable effectiveness of tree-based theory for networks with clustering. Physical Review E 83. March 2011.

Michael Molloy and Bruce Reed. A critical point for random graphs with a given degree sequence. Random Structures and Algorithms 6 (2–3). March–May 1996.

M.E.J. Newman. Spread of epidemic disease on networks. Physical Review E 66. July 2002.

M.E.J. Newman, Steven Strogatz, and Duncan Watts. Random graphs with arbitrary degree distributions and their applications. Physical Review E 64. 2001.

M.E.J. Newman and R.M. Ziff. Efficient Monte Carlo algorithm and high-precision results for percolation. Physical Review Letters 85. November 2000.

Herbert Wilf. generatingfunctionology. Academic Press. 1994.

Giulio Burgio, Alex Arenas, Sergio Gómez and Joan T. Matamalas:

  Network clique cover approximation to analyze complex contagions through group interactions, Comms. Phys. (2021) in press (arXiv:2101.03618)